@@ -23,7 +23,6 @@ r"""Python bindings for liblouis
 """
 
 from distutils.core import setup
-import louis
 
 classifiers = [
     'Development Status :: 4 - Beta',
@@ -35,8 +34,8 @@ classifiers = [
 
 setup(name="louis",
       description=__doc__,
-      download_url = "http://code.google.com/p/liblouis/",
-      license="LGPLv2.2",
+      download_url = "https://github.com/liblouis/liblouis",
+      license="LGPLv2.1+",
       classifiers=classifiers,
-      version=louis.version().split(',')[0].split('-',1)[-1],
+      version='3.5.0',
       packages=["louis"])
