@@ -21,14 +21,13 @@ main(int argc, char **argv)
 
   const char* txt = "Fussball-Vereinigung";
 
-  const char* table = "inpos_match_replace.ctb";
+  const char* table = "tests/tables/inpos_match_replace.ctb";
 
   const char* brl = "FUSSBALL-V7EINIGUNG";
 
   const int inpos[] = {0,1,2,3,4,5,6,7,8,9,9,12,13,14,15,16,17,18,19};
 
-  result |= check_translation(table, txt, NULL, brl);
-  result |= check_inpos(table, txt, inpos);
+  result |= check(table, txt, brl, .expected_inputPos=inpos);
 
   lou_free();
 
