@@ -19,7 +19,7 @@ main(int argc, char **argv)
     int i;
     int result = 0;
 
-    char* table = "pass0_typebuf.ctb";
+    char* table = "tests/tables/pass0_typebuf.ctb";
     char* text = "foo baz";
     char* expected = "foobar .baz";
     formtype* typeform = malloc(20 * sizeof(formtype));
@@ -28,7 +28,7 @@ main(int argc, char **argv)
     for (i = 4; i < 7; i++)
       typeform[i] = 1;
 
-    result = check_translation(table, text, typeform, expected);
+    result = check(table, text, expected, .typeform=typeform);
 
     lou_free();
 
