@@ -17,14 +17,14 @@ int
 main(int argc, char **argv)
 {
 
-  const char* table = "pass2.ctb";
+  const char* table = "tests/tables/pass2.ctb";
   int result = 0;
 
   /* First check a plain word to see if the table works */
-  result = check_translation(table, "Rene", NULL, "rene");
+  result = check(table, "Rene", "rene");
 
   /* then try a word which uses pass2 */
-  result |= check_translation(table, "Reno", NULL, "ren'o");
+  result |= check(table, "Reno", "ren'o");
 
   lou_free();
 
