@@ -105,18 +105,18 @@ int main(int argc, char **argv)
   int tests_len = sizeof(tests)/sizeof(char*);
 
   for (i = 0; i < tests_len; i += 2)
-    result |= check_translation("squash_space_with_repeated.utb", tests[i], NULL, tests[i+1]);
+    result |= check("tests/tables/squash_space_with_repeated.utb", tests[i], tests[i+1]);
 
   tests_len = sizeof(strings)/sizeof(char*);
 
   for (i = 0; i < tests_len; i++)
-    result |= check_translation("squash_space_with_correct.utb", strings[i], NULL, expected);
+    result |= check("tests/tables/squash_space_with_correct.utb", strings[i], expected);
 
   for (i = 0; i < tests_len; i++)
-    result |= check_translation("squash_space_with_context_1.utb", strings[i], NULL, expected);
+    result |= check("tests/tables/squash_space_with_context_1.utb", strings[i], expected);
 
   for (i = 0; i < tests_len; i++)
-    result |= check_translation("squash_space_with_context_2.utb", strings[i], NULL, expected);
+    result |= check("tests/tables/squash_space_with_context_2.utb", strings[i], expected);
 
   lou_free();
 
